'use strict';

exports.__esModule = true;
exports.cellLookup = exports.DropdownCell = exports.PasswordCell = exports.HandsontableCell = exports.TimeCell = exports.DateCell = exports.NumericCell = exports.TextCell = exports.CheckboxCell = exports.AutocompleteCell = undefined;

var _browser = require('./helpers/browser');

var _editors = require('./editors');

var _renderers = require('./renderers');

var _autocompleteEditor = require('./editors/autocompleteEditor');

var _autocompleteEditor2 = _interopRequireDefault(_autocompleteEditor);

var _checkboxEditor = require('./editors/checkboxEditor');

var _checkboxEditor2 = _interopRequireDefault(_checkboxEditor);

var _dateEditor = require('./editors/dateEditor');

var _dateEditor2 = _interopRequireDefault(_dateEditor);

var _dropdownEditor = require('./editors/dropdownEditor');

var _dropdownEditor2 = _interopRequireDefault(_dropdownEditor);

var _handsontableEditor = require('./editors/handsontableEditor');

var _handsontableEditor2 = _interopRequireDefault(_handsontableEditor);

var _mobileTextEditor = require('./editors/mobileTextEditor');

var _mobileTextEditor2 = _interopRequireDefault(_mobileTextEditor);

var _numericEditor = require('./editors/numericEditor');

var _numericEditor2 = _interopRequireDefault(_numericEditor);

var _passwordEditor = require('./editors/passwordEditor');

var _passwordEditor2 = _interopRequireDefault(_passwordEditor);

var _selectEditor = require('./editors/selectEditor');

var _selectEditor2 = _interopRequireDefault(_selectEditor);

var _textEditor = require('./editors/textEditor');

var _textEditor2 = _interopRequireDefault(_textEditor);

var _autocompleteRenderer = require('./renderers/autocompleteRenderer');

var _autocompleteRenderer2 = _interopRequireDefault(_autocompleteRenderer);

var _checkboxRenderer = require('./renderers/checkboxRenderer');

var _checkboxRenderer2 = _interopRequireDefault(_checkboxRenderer);

var _htmlRenderer = require('./renderers/htmlRenderer');

var _htmlRenderer2 = _interopRequireDefault(_htmlRenderer);

var _numericRenderer = require('./renderers/numericRenderer');

var _numericRenderer2 = _interopRequireDefault(_numericRenderer);

var _passwordRenderer = require('./renderers/passwordRenderer');

var _passwordRenderer2 = _interopRequireDefault(_passwordRenderer);

var _textRenderer = require('./renderers/textRenderer');

var _textRenderer2 = _interopRequireDefault(_textRenderer);

var _autocompleteValidator = require('./validators/autocompleteValidator');

var _autocompleteValidator2 = _interopRequireDefault(_autocompleteValidator);

var _dateValidator = require('./validators/dateValidator');

var _dateValidator2 = _interopRequireDefault(_dateValidator);

var _timeValidator = require('./validators/timeValidator');

var _timeValidator2 = _interopRequireDefault(_timeValidator);

var _numericValidator = require('./validators/numericValidator');

var _numericValidator2 = _interopRequireDefault(_numericValidator);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var AutocompleteCell = exports.AutocompleteCell = {
  editor: (0, _editors.getEditorConstructor)('autocomplete'),
  renderer: (0, _renderers.getRenderer)('autocomplete'),
  validator: _autocompleteValidator2.default
}; /**
    * Cell type is just a shortcut for setting bunch of cellProperties (used in getCellMeta)
    */

var CheckboxCell = exports.CheckboxCell = {
  editor: (0, _editors.getEditorConstructor)('checkbox'),
  renderer: (0, _renderers.getRenderer)('checkbox')
};

var TextCell = exports.TextCell = {
  editor: (0, _browser.isMobileBrowser)() ? (0, _editors.getEditorConstructor)('mobile') : (0, _editors.getEditorConstructor)('text'),
  renderer: (0, _renderers.getRenderer)('text')
};

var NumericCell = exports.NumericCell = {
  editor: (0, _editors.getEditorConstructor)('numeric'),
  renderer: (0, _renderers.getRenderer)('numeric'),
  validator: _numericValidator2.default,
  dataType: 'number'
};

var DateCell = exports.DateCell = {
  editor: (0, _editors.getEditorConstructor)('date'),
  validator: _dateValidator2.default,
  // displays small gray arrow on right side of the cell
  renderer: (0, _renderers.getRenderer)('autocomplete')
};

var TimeCell = exports.TimeCell = {
  editor: (0, _editors.getEditorConstructor)('text'),
  validator: _timeValidator2.default,
  // displays small gray arrow on right side of the cell
  renderer: (0, _renderers.getRenderer)('text')
};

var HandsontableCell = exports.HandsontableCell = {
  editor: (0, _editors.getEditorConstructor)('handsontable'),
  // displays small gray arrow on right side of the cell
  renderer: (0, _renderers.getRenderer)('autocomplete')
};

var PasswordCell = exports.PasswordCell = {
  editor: (0, _editors.getEditorConstructor)('password'),
  renderer: (0, _renderers.getRenderer)('password'),
  copyable: false
};

var DropdownCell = exports.DropdownCell = {
  editor: (0, _editors.getEditorConstructor)('dropdown'),
  // displays small gray arrow on right side of the cell
  renderer: (0, _renderers.getRenderer)('autocomplete'),
  validator: _autocompleteValidator2.default
};

// here setup the friendly aliases that are used by cellProperties.renderer and cellProperties.editor
var cellLookup = exports.cellLookup = {
  validator: {
    numeric: _numericValidator2.default,
    autocomplete: _autocompleteValidator2.default
  }
};

// here setup the friendly aliases that are used by cellProperties.type
var cellTypes = {
  text: TextCell,
  date: DateCell,
  time: TimeCell,
  numeric: NumericCell,
  checkbox: CheckboxCell,
  autocomplete: AutocompleteCell,
  handsontable: HandsontableCell,
  password: PasswordCell,
  dropdown: DropdownCell
};

exports.default = cellTypes;